@@ -12,7 +12,7 @@ class soundkonverter_codec_aften : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_aften( QObject *parent, const QStringList& args );
+    soundkonverter_codec_aften( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_aften();
@@ -33,9 +33,5 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( aften, soundkonverter_codec_aften )
-
 
 #endif // _SOUNDKONVERTER_CODEC_AFTEN_H_
-
-
