@@ -12,7 +12,7 @@ class soundkonverter_codec_flake : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_flake( QObject *parent, const QStringList& args );
+    soundkonverter_codec_flake( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_flake();
@@ -33,9 +33,4 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( flake, soundkonverter_codec_flake )
-
-
 #endif // _SOUNDKONVERTER_CODEC_FLAKE_H_
-
-
