@@ -4,6 +4,7 @@
 
 #include "../../core/codecplugin.h"
 
+
 class ConversionOptions;
 
 
@@ -12,7 +13,7 @@ class soundkonverter_codec_mac : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_mac( QObject *parent, const QStringList& args );
+    soundkonverter_codec_mac( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_mac();
@@ -33,9 +34,4 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( mac, soundkonverter_codec_mac )
-
-
 #endif // _SOUNDKONVERTER_CODEC_MAC_H_
-
-
