@@ -12,7 +12,7 @@ class soundkonverter_codec_mplayer : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_mplayer( QObject *parent, const QStringList& args );
+    soundkonverter_codec_mplayer( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_mplayer();
@@ -38,9 +38,4 @@ private:
 
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( mplayer, soundkonverter_codec_mplayer )
-
-
 #endif // SOUNDKONVERTER_CODEC_MPLAYER_H
-
-
