@@ -11,9 +11,11 @@ public:
     ~MusePackConversionOptions();
 
     bool equals( ConversionOptions *_other );
-    QDomElement toXml( QDomDocument document );
+    QDomElement toXml( QDomDocument document ) const;
     bool fromXml( QDomElement conversionOptions, QList<QDomElement> *filterOptionsElements = 0 );
 
+    ConversionOptions* copy() const;
+
     struct Data {
         enum Preset {
             Telephone = 0,
