@@ -12,7 +12,7 @@ class soundkonverter_codec_neroaac : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_neroaac( QObject *parent, const QStringList& args );
+    soundkonverter_codec_neroaac( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_neroaac();
@@ -38,9 +38,4 @@ private slots:
     void processOutput();
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( neroaac, soundkonverter_codec_neroaac )
-
-
 #endif // _SOUNDKONVERTER_CODEC_NEROAAC_H_
-
-
