@@ -12,7 +12,7 @@ class soundkonverter_codec_shorten : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_shorten( QObject *parent, const QStringList& args );
+    soundkonverter_codec_shorten( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_shorten();
@@ -33,9 +33,4 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( shorten, soundkonverter_codec_shorten )
-
-
 #endif // _SOUNDKONVERTER_CODEC_SHORTEN_H_
-
-
