@@ -12,7 +12,7 @@ class soundkonverter_codec_timidity : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_timidity( QObject *parent, const QStringList& args );
+    soundkonverter_codec_timidity( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_timidity();
@@ -32,9 +32,4 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( timidity, soundkonverter_codec_timidity )
-
-
 #endif // SOUNDKONVERTER_CODEC_TIMIDITY_H
-
-
