@@ -12,7 +12,7 @@ class soundkonverter_codec_ttaenc : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_ttaenc( QObject *parent, const QStringList& args );
+    soundkonverter_codec_ttaenc( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_ttaenc();
@@ -33,9 +33,4 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( ttaenc, soundkonverter_codec_ttaenc )
-
-
 #endif // _SOUNDKONVERTER_CODEC_TTAENC_H_
-
-
