@@ -12,7 +12,7 @@ class soundkonverter_codec_vorbistools : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_vorbistools( QObject *parent, const QStringList& args );
+    soundkonverter_codec_vorbistools( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_vorbistools();
@@ -32,9 +32,4 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( vorbistools, soundkonverter_codec_vorbistools )
-
-
 #endif // SOUNDKONVERTER_CODEC_VORBISTOOLS_H
-
-
