@@ -12,7 +12,7 @@ class soundkonverter_codec_wavpack : public CodecPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_codec_wavpack( QObject *parent, const QStringList& args );
+    soundkonverter_codec_wavpack( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_codec_wavpack();
@@ -33,9 +33,4 @@ public:
     float parseOutput( const QString& output );
 };
 
-K_EXPORT_SOUNDKONVERTER_CODEC( wavpack, soundkonverter_codec_wavpack )
-
-
 #endif // _SOUNDKONVERTER_CODEC_WAVPACK_H_
-
-
