@@ -17,13 +17,14 @@
 #include <KLineEdit>
 
 
+// TODO clean up use of modeChanged()
+
 SoxCodecWidget::SoxCodecWidget()
     : CodecWidget(),
     currentFormat( "" )
 {
     QGridLayout *grid = new QGridLayout( this );
     grid->setContentsMargins( 0, 0, 0, 0 );
-    grid->setSpacing( 6 );
 
     // set up encoding options selection
 
@@ -161,12 +162,12 @@ ConversionOptions *SoxCodecWidget::currentConversionOptions()
     return options;
 }
 
-bool SoxCodecWidget::setCurrentConversionOptions( ConversionOptions *_options )
+bool SoxCodecWidget::setCurrentConversionOptions( const ConversionOptions *_options )
 {
     if( !_options || _options->pluginName != global_plugin_name )
         return false;
 
-    ConversionOptions *options = _options;
+    const ConversionOptions *options = _options;
 
     if( currentFormat == "wav" ||
         currentFormat == "aiff" ||
@@ -224,6 +225,8 @@ void SoxCodecWidget::setCurrentFormat( const QString& format )
         lCompressionLevel->show();
         sCompressionLevel->show();
         iCompressionLevel->show();
+        sCompressionLevel->setToolTip( i18n("Compression level from %1 to %2 where %2 is the best compression.\nThe better the compression, the slower the conversion but the smaller the file size and vice versa.", 0, 8) );
+        iCompressionLevel->setToolTip( i18n("Compression level from %1 to %2 where %2 is the best compression.\nThe better the compression, the slower the conversion but the smaller the file size and vice versa.", 0, 8) );
 
         lMode->hide();
         cMode->hide();
@@ -254,6 +257,8 @@ void SoxCodecWidget::setCurrentFormat( const QString& format )
         dQuality->setSuffix( " kbps" );
         sQuality->setValue( 160 );
         dQuality->setValue( 160 );
+        sQuality->setToolTip( "" );
+        dQuality->setToolTip( "" );
 
         lBitratePreset->hide();
         cBitratePreset->hide();
@@ -294,6 +299,8 @@ void SoxCodecWidget::setCurrentFormat( const QString& format )
         dQuality->setSuffix( "" );
         sQuality->setValue( 400 );
         dQuality->setValue( 4.0 );
+        sQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", -1, 10) );
+        dQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", -1, 10) );
 
         lBitratePreset->hide();
         cBitratePreset->hide();
@@ -621,7 +628,8 @@ void SoxCodecWidget::modeChanged( int mode )
         dQuality->setValue( 5 );
         //dQuality->setValue( qualityForBitrate(dQuality->value()) );
         //qualitySpinBoxChanged( dQuality->value() );
-        dQuality->setToolTip( i18n("Quality level from 9 to 0 where 0 is the highes quality.") );
+        sQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 9, 0) );
+        dQuality->setToolTip( i18n("Quality level from %1 to %2 where %2 is the highest quality.\nThe higher the quality, the bigger the file size and vice versa.", 9, 0) );
     }
     else
     {
@@ -635,6 +643,8 @@ void SoxCodecWidget::modeChanged( int mode )
         dQuality->setValue( 160 );
         //dQuality->setValue( bitrateForQuality(dQuality->value()) );
         //qualitySpinBoxChanged( dQuality->value() );
+        sQuality->setToolTip( "" );
+        dQuality->setToolTip( "" );
     }
 }
 
