@@ -14,7 +14,7 @@ class soundkonverter_replaygain_metaflac : public ReplayGainPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_replaygain_metaflac( QObject *parent, const QStringList& args );
+    soundkonverter_replaygain_metaflac( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_replaygain_metaflac();
@@ -33,9 +33,4 @@ public:
 
 };
 
-K_EXPORT_SOUNDKONVERTER_REPLAYGAIN( metaflac, soundkonverter_replaygain_metaflac )
-
-
 #endif // _SOUNDKONVERTER_REPLAYGAIN_METAFLAC_H_
-
-
