@@ -19,7 +19,7 @@ Mp3GainPluginItem::~Mp3GainPluginItem()
 {}
 
 
-soundkonverter_replaygain_mp3gain::soundkonverter_replaygain_mp3gain( QObject *parent, const QStringList& args  )
+soundkonverter_replaygain_mp3gain::soundkonverter_replaygain_mp3gain( QObject *parent, const QVariantList& args  )
     : ReplayGainPlugin( parent )
 {
     Q_UNUSED(args)
@@ -318,6 +318,6 @@ float soundkonverter_replaygain_mp3gain::parseOutput( const QString& output )
     return progress;
 }
 
+K_PLUGIN_FACTORY(replaygain_mp3gain, registerPlugin<soundkonverter_replaygain_mp3gain>();)
+
 #include "soundkonverter_replaygain_mp3gain.moc"
-
-
