@@ -14,16 +14,13 @@ class soundkonverter_replaygain_musepackgain : public ReplayGainPlugin
     Q_OBJECT
 public:
     /** Default Constructor */
-    soundkonverter_replaygain_musepackgain( QObject *parent, const QStringList& args );
+    soundkonverter_replaygain_musepackgain( QObject *parent, const QVariantList& args );
 
     /** Default Destructor */
     ~soundkonverter_replaygain_musepackgain();
 
     QString name() const;
 
-    /** search for the backend binaries in the given directories */
-    virtual void scanForBackends( const QStringList& directoryList = QStringList() );
-
     QList<ReplayGainPipe> codecTable();
 
     bool isConfigSupported( ActionType action, const QString& codecName );
@@ -36,9 +33,4 @@ public:
 
 };
 
-K_EXPORT_SOUNDKONVERTER_REPLAYGAIN( musepackgain, soundkonverter_replaygain_musepackgain )
-
-
 #endif // _SOUNDKONVERTER_REPLAYGAIN_MUSEPACKGAIN_H_
-
-
